@@ -52,6 +52,7 @@ from ..io.IOExceptions import (
 from ...sql.sql import SQLMixin
 from ...tasks.DoOnce import DoOnce
 from .mixins.read_mixin import ReadPropertyMultiple, ReadProperty
+from .Virtuals import VirtualPoint
 
 from ..utils.notes import note_and_log
 
@@ -136,7 +137,8 @@ class Device(SQLMixin):
         auto_save=False,
         save_resampling="1s",
         clear_history_on_save=False,
-        history_size=None
+        history_size=None,
+        reconnect_on_failure=True
     ):
 
         self.properties = DeviceProperties()
@@ -155,6 +157,7 @@ class Device(SQLMixin):
         self.properties.save_resampling = save_resampling
         self.properties.clear_history_on_save = clear_history_on_save
         self.properties.default_history_size = history_size
+        self._reconnect_on_failure = reconnect_on_failure
 
         self.segmentation_supported = segmentation_supported
         self.custom_object_list = object_list
@@ -540,8 +543,11 @@ class DeviceConnected(Device):
             self.segmentation_supported = False
             self.new_state(DeviceDisconnected)
         except IndexError as error:
-            self._log.error("Device creation failed... disconnecting")
-            self.new_state(DeviceDisconnected)
+            if self._reconnect_on_failure:
+                self._log.error("Device creation failed... re-connecting")
+                self.new_state(DeviceDisconnected)
+            else:
+                self._log.error("Device creation failed... disconnecting")
 
     def __getitem__(self, point_name):
         """
@@ -591,6 +597,14 @@ class DeviceConnected(Device):
         """
         return value in self.points_name
 
+    @property
+    def pollable_points_name(self):
+        for each in self.points:
+            if not isinstance(each, VirtualPoint):
+                yield each.properties.name
+            else:
+                continue
+
     @property
     def points_name(self):
         for each in self.points:
@@ -718,24 +732,27 @@ class DeviceConnected(Device):
         return val
 
     def write_property(self, prop, value, priority=None):
-        if priority is not None:
-            priority = "- {}".format(priority)
-        if isinstance(prop, tuple):
-            _obj, _instance, _prop = prop
+        if prop == "description":
+            self.update_description(value)
         else:
-            raise ValueError(
-                "Please provide property using tuple with object, instance and property"
-            )
-        try:
-            request = "{} {} {} {} {} {}".format(
-                self.properties.address, _obj, _instance, _prop, value, priority
-            )
-            val = self.properties.network.write(
-                request, vendor_id=self.properties.vendor_id
-            )
-        except KeyError as error:
-            raise Exception("Unknown property : {}".format(error))
-        return val
+            if priority is not None:
+                priority = "- {}".format(priority)
+            if isinstance(prop, tuple):
+                _obj, _instance, _prop = prop
+            else:
+                raise ValueError(
+                    "Please provide property using tuple with object, instance and property"
+                )
+            try:
+                request = "{} {} {} {} {} {}".format(
+                    self.properties.address, _obj, _instance, _prop, value, priority
+                )
+                val = self.properties.network.write(
+                    request, vendor_id=self.properties.vendor_id
+                )
+            except KeyError as error:
+                raise Exception("Unknown property : {}".format(error))
+            return val
 
     def update_bacnet_properties(self):
         """
@@ -751,6 +768,8 @@ class DeviceConnected(Device):
                 prop_id_required=True,
             )
             for each in res:
+                if not each:
+                    continue
                 v, prop = each
                 self.properties.bacnet_properties[prop] = v
 
@@ -766,6 +785,16 @@ class DeviceConnected(Device):
     def bacnet_properties(self):
         return self._bacnet_properties(update=True)
 
+    def update_description(self, value):
+        self.properties.network.send_text_write_request(
+            addr=self.properties.address,
+            obj_type="device",
+            obj_inst=int(self.device_id),
+            value=value,
+            prop_id="description",
+        )
+        self.properties.description = self.read_property("description")
+
     def __repr__(self):
         return "{} / Connected".format(self.properties.name)
 
@@ -848,6 +877,7 @@ class DeviceDisconnected(Device):
                 self.new_state(RPDeviceConnected)
 
             except (NoResponseFromController, AttributeError) as error:
+                self._log.warning("Error connecting: %s", error)
                 if self.properties.db_name:
                     self.new_state(DeviceFromDB)
                 else:
